/* ****************************************************************** */
/*     LIESCHEN.INC                                                   */
/*                                                                    */
/*     11.10.95    STS     Creation                                   */
/*     13.10.95    STS     Documentation                              */
/*     21. 8.04    KHS     Conversion to PL/I                         */
/* ****************************************************************** */

  /* Lieschen block */
  Declare
   /* Name of the spectrometer */
           Cspectro Char(20) Var Ext,
   /* projectile isotop and primary energy */
           (AP, ZP, TP,
   /* target material, thickness, backing and correction factor */
            AT, ZT, DT, ATQ, ZTQ, DTQ, FT,
   /* degrader S1 material, thickness */
            ADS1, ZDS1, DDS1,
   /* degrader material, thickness, backing and correction factor */
            AD, ZD, DD, ADQ, ZDQ, DDQ, FD,
       /* Second degrader for SFRS */
            AD2, ZD2, DD2, ADQ2, ZDQ2, DDQ2, FD2,
   /* degrader offset (e.g. scintillator) */
            DKOFFS, DKOFFS2,
   /* slope of degrader slope [cm/%]
                  (second one seems not be used anywhere) */
            XK, XKDEG,
            XK2, XKDEG2,
   /* stopper material and correction factor */
            AS, ZS, FS,
   /* fragment selected by user */
            AFS, ZFS,
   /* matter layers at the exit of the FRS */
            AM(100), ZM(100), DM(100) ) Dec Float(6) Ext,
   /* character backup in input.for */
            NAMEM(100) Char(40) Var Ext,
   /* charge states of selected fragment behind target */
           (Q1FS, Q2FS, Q3FS, Q4FS,
   /* charge states of selected fragment before 1st and 2nd stage */
            Q01FA, Q12FA, Q1FA, Q2FA, Q3FA, Q4FA,
   /* charge states of selected fragment behind 1st and 2nd stage */
            Q01FB, Q12FB, Q1FB, Q2FB, Q3FB, Q4FB,
   /* --- ionoptical parameters: --- */
     /* dispersion of 1st and 2nd stage, S0-S1, S1-S2 */
            DISP1, DISP2, DISP01, DISP12, DISP3, DISP4,
     /* magnification of 1st and 2nd stage, S0-S1, S1-S2 */
            V1, V2, V01, V12, V3, V4,
     /* length in meter */
            L1, L2, L01, L02, L3, L4,
     /* momentum acceptance */
            AC1, AC2, AC01, AC02, AC3, AC4,
     /* angular acceptance */
            AAC1, AAC2, AAC01, AAC02, AAC3, AAC4,
     /* aberration in momentum */
            ABP1, ABP2, ABP3, ABP4,
     /* chromatic aberration */
            ABC1, ABC2, ABC3, ABC4,
     /* spherical aberration */
            ABS1, ABS2, ABS3, ABS4,
   /* --- Gaussian sigma widths of: --- */
     /* position and angle of projectile before the target (beam spot)*/
            SIGX0, SIGA0,
     /* position and angle behind the degrader */
            SIGDEG, SIGADEG,
        /* values of second degrader for SFRS */
            SIGDEG2, SIGADEG2,
   /* magnetic rigidity and radius of 1st and 2nd stage
                             (3rd and 4th stage of SFRS) */
            R01, BRHO1, R1, BRHO2, R2, BRHO3, R3, BRHO4, R4,
   /* separate values of first two dipoles, if S1 degrader is used */
            BRHO01, BRHO12,
   /* special values for the LISE (etc.) spectrometer */
            EWIEN, BWIEN, BWIENFAC, LEWIEN, LBWIEN, DISFOC)
                     Dec Float(6) External,
   /* --- codes for: --- */
     /* spectrometer type: */
     /* 1=FRS, 2=LISE3, 3=LISE, 4=A1200, 5=RIPS, 6=ALPHA, 7=SFRS */
           (ISPEC,
   /* energy range */
            IENER,
   /* --- degrader shaping: -- */
     /* 1=achromatic, 2=monoenergetic, 3=homogenous, */
     /* 4=special formed, 5=sepcial FRS degrader and */
     /* 6=users own definition (see IDEGCUT below) */
            IDEG, IDEG2,
   /* calculation with contaminants (=1, not=0) */
            ICONT,
   /* first DISTRI run (=0) for selected fragment */
            IFIRST,
   /* degrader shape following user-defined slope [cm/%] */
            IDEGCUT,
   /* value meaning: 0='   'and 1='EXP' */
            IEXP) Bin Fixed(31) External,
   /* brho refernce values for 1st and 2nd stage */
           (BR1REF, BR2REF, BR3REF, BR4REF,
   /* limits (=maximum) magnetic rigidity of the two stages */
            BR1LIM, BR2LIM, BR3LIM, BR4LIM)
              Dec Float(6) External,
   /* program version of Lieschen */
            CVERS Char(5) Var External,
   /* output: NUL, LPT1 or LIESCHEN.TXT */
            CPRINT Char(8) Var External,
   /* reference dataset for magnet values
                (see scaling factor for MGSCAL */
            DSNREF Char(40) Var External;